=== modified file 'NEWS'
--- NEWS	2007-07-31 05:10:59 +0000
+++ NEWS	2007-08-03 02:52:23 +0000
@@ -190,6 +190,10 @@
     * The SSH_AUTH_SOCK environment variable is now reset to avoid 
       interaction with any running ssh agents.  (Jelmer Vernooij, #125955)
 
+    * run_bzr_subprocess handles parameters the same way as run_bzr:
+      either a string or a list of strings should be passed as the first
+      parameter.  Varargs-style parameters are deprecated. (Aaron Bentley)
+
 
 bzr 0.18  2007-07-17
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2007-07-27 06:15:32 +0000
+++ bzrlib/tests/__init__.py	2007-08-03 02:52:23 +0000
@@ -80,6 +80,7 @@
 from bzrlib.symbol_versioning import (
     deprecated_method,
     zero_eighteen,
+    zero_nineteen,
     )
 import bzrlib.trace
 from bzrlib.transport import get_transport
@@ -1422,6 +1423,15 @@
         env_changes = kwargs.get('env_changes', {})
         working_dir = kwargs.get('working_dir', None)
         allow_plugins = kwargs.get('allow_plugins', False)
+        if len(args) == 1:
+            if isinstance(args[0], list):
+                args = args[0]
+            elif isinstance(args[0], basestring):
+                args = list(shlex.split(args[0]))
+        else:
+            symbol_versioning.warn(zero_nineteen %
+                                   "passing varargs to run_bzr",
+                                   DeprecationWarning, stacklevel=3)
         process = self.start_bzr_subprocess(args, env_changes=env_changes,
                                             working_dir=working_dir,
                                             allow_plugins=allow_plugins)

=== modified file 'bzrlib/tests/blackbox/test_cat.py'
--- bzrlib/tests/blackbox/test_cat.py	2007-06-26 20:32:49 +0000
+++ bzrlib/tests/blackbox/test_cat.py	2007-08-03 02:52:23 +0000
@@ -28,7 +28,7 @@
     def test_cat(self):
 
         def bzr(*args, **kwargs):
-            return self.run_bzr_subprocess(*args, **kwargs)[0]
+            return self.run_bzr_subprocess(list(args), **kwargs)[0]
 
         os.mkdir('branch')
         os.chdir('branch')

=== modified file 'bzrlib/tests/blackbox/test_debug.py'
--- bzrlib/tests/blackbox/test_debug.py	2007-07-05 00:12:25 +0000
+++ bzrlib/tests/blackbox/test_debug.py	2007-08-03 02:52:23 +0000
@@ -18,7 +18,6 @@
 
 import os
 import signal
-import subprocess
 import sys
 import time
 

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2007-07-04 08:49:15 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2007-08-03 02:52:23 +0000
@@ -282,8 +282,7 @@
         orig_progress = os.environ.get('BZR_PROGRESS_BAR')
         try:
             os.environ['BZR_PROGRESS_BAR'] = 'none'
-            out, err = self.run_bzr_subprocess('diff', '-r', '1',
-                                               '--diff-options', '-ub',
+            out, err = self.run_bzr_subprocess('diff -r 1 --diff-options -ub',
                                                universal_newlines=True,
                                                retcode=None)
         finally:

=== modified file 'bzrlib/tests/blackbox/test_locale.py'
--- bzrlib/tests/blackbox/test_locale.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/blackbox/test_locale.py	2007-08-03 02:52:23 +0000
@@ -41,8 +41,8 @@
         self.tree = tree
 
     def test_log_C(self):
-        out, err = self.run_bzr_subprocess('--no-aliases', '--no-plugins',
-               '-q', 'log', '--log-format=long', 'tree',
+        out, err = self.run_bzr_subprocess(
+            '--no-aliases --no-plugins -q log --log-format=long tree',
                env_changes={'LANG':'C', 'BZR_PROGRESS_BAR':'none',
                             'LC_ALL':None, 'LC_CTYPE':None, 'LANGUAGE':None})
         self.assertEqual('', err)
@@ -57,8 +57,8 @@
 """, out)
 
     def test_log_BOGUS(self):
-        out, err = self.run_bzr_subprocess('--no-aliases', '--no-plugins',
-               '-q', 'log', '--log-format=long', 'tree',
+        out, err = self.run_bzr_subprocess(
+            '--no-aliases --no-plugins -q log --log-format=long tree',
                env_changes={'LANG':'BOGUS', 'BZR_PROGRESS_BAR':'none',
                             'LC_ALL':None, 'LC_CTYPE':None, 'LANGUAGE':None})
         # XXX: This depends on the exact formatting of a locale.Error

=== modified file 'bzrlib/tests/blackbox/test_selftest.py'
--- bzrlib/tests/blackbox/test_selftest.py	2007-07-11 01:44:46 +0000
+++ bzrlib/tests/blackbox/test_selftest.py	2007-08-03 02:52:23 +0000
@@ -266,6 +266,7 @@
     def test_run_bzr_subprocess(self):
         """The run_bzr_helper_external comand behaves nicely."""
         result = self.run_bzr_subprocess('--version')
+        result = self.run_bzr_subprocess(['--version'])
         result = self.run_bzr_subprocess('--version', retcode=None)
         self.assertContainsRe(result[0], 'is free software')
         self.assertRaises(AssertionError, self.run_bzr_subprocess, 
@@ -273,7 +274,7 @@
         result = self.run_bzr_subprocess('--versionn', retcode=3)
         result = self.run_bzr_subprocess('--versionn', retcode=None)
         self.assertContainsRe(result[1], 'unknown command')
-        err = self.run_bzr_subprocess('merge', '--merge-type', 'magic merge', 
+        err = self.run_bzr_subprocess('merge --merge-type magic\ merge',
                                       retcode=3)[1]
         self.assertContainsRe(err, 'Bad value "magic merge" for option'
                               ' "merge-type"')
@@ -388,7 +389,7 @@
         raise _DontSpawnProcess()
 
     def test_run_bzr_subprocess_no_plugins(self):
-        self.assertRaises(_DontSpawnProcess, self.run_bzr_subprocess)
+        self.assertRaises(_DontSpawnProcess, self.run_bzr_subprocess, '')
         command = self._popen_args[0]
         self.assertEqual(sys.executable, command[0])
         self.assertEqual(self.get_bzr_path(), command[1])
@@ -396,7 +397,7 @@
 
     def test_allow_plugins(self):
         self.assertRaises(_DontSpawnProcess,
-                          self.run_bzr_subprocess, allow_plugins=True)
+                          self.run_bzr_subprocess, '', allow_plugins=True)
         command = self._popen_args[0]
         self.assertEqual([], command[2:])
 

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2007-07-31 02:58:48 +0000
+++ bzrlib/tests/blackbox/test_send.py	2007-08-03 02:52:23 +0000
@@ -101,7 +101,7 @@
         # which would break patch-based bundles
         self.make_trees()        
         os.chdir('branch')
-        stdout = self.run_bzr_subprocess('send', '-o-')[0]
+        stdout = self.run_bzr_subprocess('send -o-')[0]
         br = read_bundle(StringIO(stdout))
         self.assertRevisions(br, ['revision3'])
 

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2007-07-20 18:59:29 +0000
+++ bzrlib/tests/test_sftp_transport.py	2007-08-03 02:52:23 +0000
@@ -334,7 +334,7 @@
         # else:
         #     self.fail('Excepted ConnectionError to be raised')
 
-        out, err = self.run_bzr_subprocess('log', self.bogus_url, retcode=3)
+        out, err = self.run_bzr_subprocess(['log', self.bogus_url], retcode=3)
         self.assertEqual('', out)
         if "NameError: global name 'SSHException'" in err:
             # We aren't fixing this bug, because it is a bug in

